// ***************************************************************************************************************************
// * Licensed to the Apache Software Foundation (ASF) under one or more contributor license agreements.  See the NOTICE file *
// * distributed with this work for additional information regarding copyright ownership.  The ASF licenses this file        *
// * to you under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance            *
// * with the License.  You may obtain a copy of the License at                                                              *
// *                                                                                                                         *
// *  http://www.apache.org/licenses/LICENSE-2.0                                                                             *
// *                                                                                                                         *
// * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an  *
// * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the        *
// * specific language governing permissions and limitations under the License.                                              *
// ***************************************************************************************************************************
package org.apache.juneau.http;

import org.apache.http.*;

/**
 * Identifies a class that can be converted to a {@link Header} object.
 * 
 * <p>
 * Typically used on {@link NameValuePair} classes to allow them to be easily converted to {@link Header}
 * objects in a controlled way.
 */
public interface Headerable {

	/**
	 * Convert the object to a {@link Header}.
	 *
	 * @return The object converted to a {@link Header}.
	 */
	Header asHeader();
}
